#!/bin/sh
#
# fhist - file history and comparison tools
# Copyright (C) 1998, 2008, 2009 Peter Miller
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 3 of the License, or (at
# your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program. If not, see <http://www.gnu.org/licenses/>.
#
sortflag=
if test "$1" = "-r"; then
    sortflag=-r
    shift
fi
echo $* |
tr ' ' '\12' |
sort $sortflag -n -t. -k 2,2.2 -k 3 |
while read f
do
    echo ".br"
    echo ".ne 2i"
    echo ".so $f"
done
exit 0
